# abtsdata: tools for processing data collected using abts

**abtsdata** is a Python package that provides a simple interface for
reprocessing data collected using the abts module built on top of
psiexperiment.
